# https://fedoraproject.org/wiki/Packaging:Haskell

%global pkg_name hledger

%bcond_with tests

Name:           %{pkg_name}
Version:        0.24
Release:        3%{?dist}
Summary:        The main command-line interface for the hledger accounting tool

License:        GPLv3
Url:            https://hackage.haskell.org/package/%{name}
Source0:        https://hackage.haskell.org/package/%{name}-%{version}/%{name}-%{version}.tar.gz
# http://www.yesodweb.com/blog/2014/04/consolidation-progress
Patch0:         hledger-0.24-req-new-shakespeare.patch
# rhbz(974725)
Patch1:         hledger-0.24-no-pretty-show.patch

BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-rpm-macros
# Begin cabal-rpm deps:
BuildRequires:  chrpath
BuildRequires:  ghc-HUnit-devel
BuildRequires:  ghc-cmdargs-devel
BuildRequires:  ghc-containers-devel
BuildRequires:  ghc-csv-devel
BuildRequires:  ghc-directory-devel
BuildRequires:  ghc-filepath-devel
BuildRequires:  ghc-haskeline-devel
BuildRequires:  ghc-hledger-lib-devel
BuildRequires:  ghc-mtl-devel
BuildRequires:  ghc-old-locale-devel
BuildRequires:  ghc-old-time-devel
BuildRequires:  ghc-parsec-devel
#BuildRequires:  ghc-pretty-show-devel
BuildRequires:  ghc-process-devel
BuildRequires:  ghc-regex-tdfa-devel
BuildRequires:  ghc-regexpr-devel
BuildRequires:  ghc-safe-devel
BuildRequires:  ghc-shakespeare-devel
BuildRequires:  ghc-split-devel
BuildRequires:  ghc-tabular-devel
BuildRequires:  ghc-text-devel
BuildRequires:  ghc-time-devel
BuildRequires:  ghc-utf8-string-devel
BuildRequires:  ghc-wizards-devel
%if %{with tests}
BuildRequires:  ghc-test-framework-devel
BuildRequires:  ghc-test-framework-hunit-devel
BuildRequires:  ghc-transformers-devel
%endif
# End cabal-rpm deps

%description
Hledger is a library and set of user tools for working with financial data (or
anything that can be tracked in a double-entry accounting ledger.) It is a
haskell port and friendly fork of John Wiegley's Ledger. hledger provides
command-line, curses and web interfaces, and aims to be a reliable, practical
tool for daily use.


%package -n ghc-%{name}
Summary:        Haskell %{name} library

%description -n ghc-%{name}
This package provides the Haskell %{name} shared library.


%package -n ghc-%{name}-devel
Summary:        Haskell %{name} library development files
Provides:       ghc-%{name}-static = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}
Requires:       ghc-%{name}%{?_isa} = %{version}-%{release}

%description -n ghc-%{name}-devel
This package provides the Haskell %{name} library development files.


%prep
%setup -q
%patch0 -p1 -b .req-new-shakespeare
%patch1 -p1 -b .no-pretty-show


%build
%ghc_lib_build


%install
%ghc_lib_install

%ghc_fix_dynamic_rpath %{pkg_name}


%check
%if %{with tests}
%cabal test
%endif


%post -n ghc-%{name}-devel
%ghc_pkg_recache


%postun -n ghc-%{name}-devel
%ghc_pkg_recache


%files
%doc LICENSE
%{_bindir}/%{name}


%files -n ghc-%{name} -f ghc-%{name}.files
%doc LICENSE


%files -n ghc-%{name}-devel -f ghc-%{name}-devel.files


%changelog
* Sat Aug 08 2015 Ben Boeckel <mathstuf@gmail.com> - 0.24-3
- rebuild for ghc-safe and ghc-wizards

* Wed Jun 17 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.24-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Sun Mar 01 2015 Ben Boeckel <mathstuf@gmail.com> - 0.24-1
- update to 0.24
- cblrpm refresh

* Fri Feb  6 2015 Jens Petersen <petersen@redhat.com> - 0.23.2-1
- update to 0.23.2
- cblrpm refresh
- patch out pretty-show for now
- try re-enabling armv7

* Sat Aug 16 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.19.3-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_22_Mass_Rebuild

* Sat Jun 07 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.19.3-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Fri Aug 30 2013 Jens Petersen <petersen@redhat.com> - 0.19.3-3
- exclude armv7hl since TemplateHaskell failing to compile (#992478)

* Sat Aug 03 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.19.3-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Wed Jun 12 2013 Jens Petersen <petersen@redhat.com> - 0.19.3-1
- update to 0.19.3
- update to new simplified Haskell Packaging Guidelines

* Tue Mar 19 2013 Jens Petersen <petersen@redhat.com> - 0.17-5
- allow haskeline-0.7

* Thu Feb 14 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.17-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_19_Mass_Rebuild

* Fri Nov  9 2012 Jens Petersen <petersen@redhat.com> - 0.17-3
- re-enable dynamic executable
- allow building with cmdargs-0.10 and split-0.2
- update with cabal-rpm

* Thu Jul 19 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.17-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Wed Feb 29 2012 Ben Boeckel <mathstuf@gmail.com> - 0.17-1
- Initial package
